@@ -35,14 +35,6 @@ static void center_window(QWidget *a)
             b->y() + (b->height() - a->height()) / 2);
 }
 
-static void move_mouse_window(QWidget *a)
-{
-    // QWidget *b = qApp->mainWidget();
-    QWidget *b = QApplication::activeWindow();
-    a->move(b->x() + (b->width() - a->width()) / 2,
-            b->y() + (b->height() - a->height()) / 2);
-}
-
 static void fix_size(QWidget *w) { w->setFixedSize(w->sizeHint()); }
 
 // Modal dialog
@@ -59,7 +51,6 @@ IntervalDialog::IntervalDialog(const char *ed_txt, bool enabled) : QDialog()
     h1->addStretch(1);
 
     lined = new QLineEdit(this);
-    QFont f = font();
     lined->setMaxLength(7);
     lined->setText(ed_txt);
     if (enabled)
@@ -134,7 +125,7 @@ void IntervalDialog::event_label_changed()
     while ((s[i] >= '0' && s[i] <= '9') || s[i] == '.')
         i++;
 
-    float period = (i > 0) ? s.left(i).toFloat() : -1;
+    float period = (i > 0) ? s.leftRef(i).toFloat() : -1;
 
     s = s.mid(i, 3).simplified();
     if (s.length() == 0 || s == "s")
@@ -149,7 +140,7 @@ void IntervalDialog::event_label_changed()
         return;
     }
 
-    txt.sprintf("%d ms", (int)period);
+    txt = QString::asprintf("%d ms", (int)period);
     label->setText(txt);
 }
 
@@ -165,7 +156,7 @@ void IntervalDialog::done_dialog()
     while ((s[i] >= '0' && s[i] <= '9') || s[i] == '.')
         i++;
 
-    float period = (i > 0) ? s.left(i).toFloat() : -1;
+    float period = (i > 0) ? s.leftRef(i).toFloat() : -1;
 
     s = s.mid(i, 3).simplified();
     if (s.length() == 0 || s == "s")
@@ -268,7 +259,7 @@ void SliderDialog::slider_change(int val)
 }
 
 // DRAFT CODE,
-PermissionDialog::PermissionDialog(QString msg, QString passwd) : QDialog()
+PermissionDialog::PermissionDialog(QString msg, QString /*passwd*/) : QDialog()
 {
     setWindowTitle( tr( "Permission" ) );
     QVBoxLayout *vbox = new QVBoxLayout;
@@ -392,7 +383,7 @@ void SchedDialog::done_dialog()
         accept();
 }
 
-void SchedDialog::button_clicked(bool val)
+void SchedDialog::button_clicked(bool /*val*/)
 {
     //	printf("SchedDialog::checked()\n");
     if (rb_other->isChecked())
