@@ -20,9 +20,9 @@
  * MA 02110-1301, USA.
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
 #include <sys/types.h> //major() minor()
 #include <sys/stat.h>
 #include <fcntl.h>
